pub struct WorktreeManager { /* private fields */ }Expand description
Manages git worktrees for workspace isolation.
Implementations
Sourceimpl WorktreeManager
impl WorktreeManager
Sourcepub fn new(repo_root: &Path) -> Self
pub fn new(repo_root: &Path) -> Self
Create a new worktree manager for the given repository root.
Sourcepub fn create(&self, prefix: &str) -> Result<WorktreeInfo, String>
pub fn create(&self, prefix: &str) -> Result<WorktreeInfo, String>
Create a new worktree with an auto-generated branch name.
Returns the worktree path and branch name.
Sourcepub fn create_at(
&self,
path: &Path,
branch: &str,
) -> Result<WorktreeInfo, String>
pub fn create_at( &self, path: &Path, branch: &str, ) -> Result<WorktreeInfo, String>
Create a worktree at a specific path with a specific branch.
Sourcepub fn list(&self) -> Vec<WorktreeInfo>
pub fn list(&self) -> Vec<WorktreeInfo>
List all worktrees.
Sourcepub fn cleanup_all(&self) -> Vec<String>
pub fn cleanup_all(&self) -> Vec<String>
Clean up all opendev-created worktrees.